
/***************************************************************************

                                 ChessV

                   COPYRIGHT (C) 2005 BY GREGORY STRONG

This file is part of ChessV.  ChessV is free software; you can redistribute
it and/or modify it under the terms of the GNU General Public License as 
published by the Free Software Foundation; either version 2 of the License, 
or (at your option) any later version.

ChessV is distributed in the hope that it will be useful, but WITHOUT ANY 
WARRANTY; without even the implied warranty of MERCHANTABILITY or 
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
more details; the file 'COPYING' contains the License text, but if for
some reason you need a copy, please write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

****************************************************************************/


#ifndef FILE__CHESS_PIECE_TYPES_H
#define FILE__CHESS_PIECE_TYPES_H


class OrthodoxRook:
	public PieceType64
{
  public:
	//	construction
	OrthodoxRook():
		PieceType64("Rook", "Rook", "R", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WRook.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BRook.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WRook.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BRook.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WRook.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BRook.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WRook.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BRook.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 0 ) );
		AddMovementCapability( MovementCapability( -1,  0, 0 ) );
		AddMovementCapability( MovementCapability(  0,  1, 0 ) );
		AddMovementCapability( MovementCapability(  0, -1, 0 ) );
		SetSquareBonuses( 0, rookSquareBonuses );
		SetSquareBonuses( 1, rookSquareBonuses );
		SetSquareBonuses( 2, rookSquareBonuses );
		SetMobility( AutomaticBitboardMobility, 0, 16 );
		SetTropismType( HVDistanceTropism );
		SetTropism( 1, -1 );
		SetTropism( 2, -3 );
		SetTropism( 3, -5 );
		SetTropism( 4, -6 );
		SetTropism( 5, -8 );
		SetTropism( 6, -8 );
		SetTropism( 7, -8 );
		baseValue = 4500;
		perCaptureValueBonus = 50;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		optimization = SimpleSlider;
		gcID[0] = 'R';
		gcID[1] = 'r';
	}

	static OrthodoxRook orthodoxRook;
};

class OrthodoxBishop:
	public PieceType64
{
  public:
	//	construction
	OrthodoxBishop():
		PieceType64("Bishop", "Bishop", "B", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WBishop.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BBishop.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WBishop.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BBishop.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WBishop.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BBishop.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WBishop.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BBishop.bmp";
		AddMovementCapability( MovementCapability(  1,  1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  1, 0 ) );
		AddMovementCapability( MovementCapability(  1, -1, 0 ) );
		AddMovementCapability( MovementCapability( -1, -1, 0 ) );
		SetSquareBonuses( 0, bishopSquareBonuses );
		SetSquareBonuses( 1, bishopSquareBonuses );
		SetSquareBonuses( 2, bishopSquareBonuses );
		SetMobility( AutomaticBitboardMobility, -8, 24 );
		SetTropismType( DistanceTropism );
		SetTropism( 1, -1 );
		SetTropism( 2, -1 );
		SetTropism( 3, -3 );
		SetTropism( 4, -5 );
		SetTropism( 5, -7 );
		SetTropism( 6, -7 );
		SetTropism( 7, -7 );
		baseValue = 3000;
		perCaptureValueBonus = 15;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		optimization = SimpleSlider;
		gcID[0] = 'B';
		gcID[1] = 'b';
	}

	static OrthodoxBishop orthodoxBishop;
//	static BitBoard64 bitboard[2];
//	static BitBoard64 moveArray[64];
};

class OrthodoxKnight:
	public PieceType64
{
  public:
	//	construction
	OrthodoxKnight():
		PieceType64("Knight", "Knight", "N", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WKnight.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BKnight.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WKnight.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BKnight.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WKnight.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BKnight.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WKnight.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BKnight.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WKnight.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BKnight.bmp";
		AddMovementCapability( MovementCapability( -1,  2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  2,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -1, 1 ) );
		AddMovementCapability( MovementCapability(  2, -1, 1 ) );
		SetSquareBonuses( 0, knightSquareBonuses );
		SetSquareBonuses( 1, knightSquareBonuses );
		SetSquareBonuses( 2, knightSquareBonuses );
		baseValue = 3000;
		armyAdjustment = 0;
		optimization = SimpleSingleStep;
		gcID[0] = 'N';
		gcID[1] = 'n';
	}

	static OrthodoxKnight orthodoxKnight;
//	static BitBoard64 bitboard[2];
//	static BitBoard64 moveArray[64];
};

class OrthodoxQueen:
	public PieceType64
{
  public:
	//	construction
	OrthodoxQueen():
		PieceType64("Queen", "Queen", "Q", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WQueen.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BQueen.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WQueen.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BQueen.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WQueen.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BQueen.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WQueen.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BQueen.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 0 ) );
		AddMovementCapability( MovementCapability( -1,  0, 0 ) );
		AddMovementCapability( MovementCapability(  0,  1, 0 ) );
		AddMovementCapability( MovementCapability(  0, -1, 0 ) );
		AddMovementCapability( MovementCapability(  1,  1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  1, 0 ) );
		AddMovementCapability( MovementCapability(  1, -1, 0 ) );
		AddMovementCapability( MovementCapability( -1, -1, 0 ) );
		SetSquareBonuses( 0, queenSquareBonuses );
		SetSquareBonuses( 1, queenSquareBonuses );
		SetSquareBonuses( 2, queenSquareBonuses );
		SetTropismType( DistanceTropism );
		SetTropism( 1, 3 );
		SetTropism( 2, 3 );
		SetTropism( 3, 2 );
		SetTropism( 4, 1 );
		baseValue = 8600;
		perCaptureValueBonus = 75;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		optimization = SimpleSlider;
		gcID[0] = 'Q';
		gcID[1] = 'q';
	}

	static OrthodoxQueen orthodoxQueen;
//	static BitBoard64 bitboard[2];
//	static BitBoard64 moveArray;
};

class OrthodoxKing:
	public PieceType64
{
  public:
	//	construction
	OrthodoxKing():
		PieceType64("King", "King", "K", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WKing.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BKing.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WKing.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BKing.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WKing.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BKing.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WKing.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BKing.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WKing.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BKing.bmp";
		AddMovementCapability( MovementCapability(  0,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		SetSquareBonuses( 0, kingSquareBonuses );
		SetSquareBonuses( 1, kingSquareBonuses );
		SetSquareBonuses( 2, endgameKingSquareBonuses );
		armyAdjustment = 0;
		optimization = SimpleSingleStep;
		isRoyal = true;
		baseValue = 0;
		gcID[0] = 'K';
		gcID[1] = 'k';
	}

	static OrthodoxKing orthodoxKing;
//	static BitBoard64 bitboard[2];
//	static BitBoard64 moveArray[64];
};

class OrthodoxPawn:
	public PieceType64
{
  public:
	//	construction
	OrthodoxPawn():
		PieceType64("Pawn", "Pawn", "P", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BPawn.bmp";
		AddMovementCapability( MovementCapability(  1, 1, 1, CaptureOnly ) );
		AddMovementCapability( MovementCapability( -1, 1, 1, CaptureOnly ) );
		AddMovementCapability( MovementCapability(  0, 1, 2, MoveOnly, 0, 15 ) );
		AddMovementCapability( MovementCapability(  0, 1, 1, MoveOnly, 16, 63 ) );
		SetSquareBonuses( 0, openingPawnSquareBonuses );
		SetSquareBonuses( 1, pawnSquareBonuses );
		SetSquareBonuses( 2, endgamePawnSquareBonuses );
		promotion.SetPromotionCapability( PromoteToVariableTypes );
		baseValue = 1000;
		armyAdjustment = 0;
		isPawn = true;
		gcID[0] = 'P';
		gcID[1] = 'p';
	}

	virtual void BB64_Initialize()
	{
		//	call base class's BB64_Initialize function
		PieceType64::BB64_Initialize();

		//	now add the single-step non-capturing move from the 
		//	starting rank; the two-step move will be handled specially by 
		//	ChessGame::GenerateMoves()
		for( int x = 0; x < 8; x++ )
		{
			bb64_direct_move_no_capture[0][x+8].SetBit( x + 16 );
			bb64_direct_move_no_capture[1][x+48].SetBit( x + 40 );
		}
	}

	static OrthodoxPawn orthodoxPawn;
//	static BitBoard64 bitboard[2];
//	static BitBoard64 moveArray[2][64];
};

class BerolinaPawn:
	public PieceType64
{
  public:
	//	construction
	BerolinaPawn():
		PieceType64("Berolina Pawn", "Pawn", "P", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BPawn.bmp";
		AddMovementCapability( MovementCapability(  1, 1, 2, MoveOnly, 0, 15 ) );
		AddMovementCapability( MovementCapability( -1, 1, 2, MoveOnly, 0, 15 ) );
		AddMovementCapability( MovementCapability(  1, 1, 1, MoveOnly, 16, 63 ) );
		AddMovementCapability( MovementCapability( -1, 1, 1, MoveOnly, 16, 63 ) );
		AddMovementCapability( MovementCapability(  0, 1, 1, CaptureOnly ) );
		SetSquareBonuses( 0, openingPawnSquareBonuses );
		SetSquareBonuses( 1, pawnSquareBonuses );
		SetSquareBonuses( 2, endgamePawnSquareBonuses );
		promotion.SetPromotionCapability( PromoteToVariableTypes );
		baseValue = 1000;
		isPawn = true;
		gcID[0] = 'S';
		gcID[1] = 's';
	}

	static BerolinaPawn berolinaPawn;
};

class LamePawn:
	public PieceType64
{
  public:
	//	construction
	LamePawn():
		PieceType64("Lame Pawn", "Pawn", "P", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BPawn.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WPawn.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BPawn.bmp";
		AddMovementCapability( MovementCapability(  1, 1, 1, CaptureOnly ) );
		AddMovementCapability( MovementCapability( -1, 1, 1, CaptureOnly ) );
		AddMovementCapability( MovementCapability(  0, 1, 1, MoveOnly ) );
		SetSquareBonuses( 0, openingPawnSquareBonuses );
		SetSquareBonuses( 1, pawnSquareBonuses );
		SetSquareBonuses( 2, endgamePawnSquareBonuses );
		promotion.SetPromotionCapability( PromoteToVariableTypes );
		baseValue = 1000;
		isPawn = true;
	}

	static LamePawn lamePawn;
};

class Elephant:
	public PieceType64
{
  public:
	//	construction
	Elephant():
		PieceType64("Elephant", "Elephant", "E", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WElephant.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BElephant.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WElephant.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BElephant.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WElephant.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BElephant.bmp";
		AddMovementCapability( MovementCapability(  2,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  2, 1 ) );
		AddMovementCapability( MovementCapability(  2, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -2, 1 ) );
		SetSquareBonuses( 0, waffleSquareBonuses );
		SetSquareBonuses( 1, waffleSquareBonuses );
		SetSquareBonuses( 2, waffleSquareBonuses );
		optimization = SimpleSingleStep;
		baseValue = 1000;
	}

	static Elephant elephant;
};

class Ferz:
	public PieceType64
{
  public:
	//	construction
	Ferz():
		PieceType64("Ferz", "General", "G", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WFerz.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BFerz.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WFers.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BFers.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WCounsellor.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BCounsellor.bmp";
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		SetSquareBonuses( 0, ferzSquareBonuses );
		SetSquareBonuses( 1, ferzSquareBonuses );
		SetSquareBonuses( 2, ferzSquareBonuses );
		optimization = SimpleSingleStep;
		baseValue = 1850;
	}

	static Ferz ferz;
};

class ElephantFerz:
	public PieceType64
{
  public:
	//	construction
	ElephantFerz():
		PieceType64("Elephant-Ferz", "Elephant", "E", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WElephantFerz.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BElephantFerz.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WElephant.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BElephant.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WElephant.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BElephant.bmp";
		AddMovementCapability( MovementCapability(  2,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  2, 1 ) );
		AddMovementCapability( MovementCapability(  2, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		SetSquareBonuses( 0, waffleSquareBonuses );
		SetSquareBonuses( 1, waffleSquareBonuses );
		SetSquareBonuses( 2, waffleSquareBonuses );
		optimization = SimpleSingleStep;
		baseValue = 2750;
	}

	static ElephantFerz elephantFerz;
};

class General:
	public PieceType64
{
  public:
	//	construction
	General():
		PieceType64("General", "General", "G", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WGuard.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BGuard.bmp";
		bitmapFileNames[PIECE_SET_ALTERNATE][0] = "images\\standard\\WGeneral.bmp";
		bitmapFileNames[PIECE_SET_ALTERNATE][1] = "images\\standard\\BGeneral.bmp";
//		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WGuard.bmp";
//		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BGuard.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WCenturion.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BCenturion.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][0] = "images\\old_world\\WCommoner.bmp";
		bitmapFileNames[PIECE_SET_OLD_WORLD][1] = "images\\old_world\\BCommoner.bmp";
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  0,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  1,  0, 1 ) );
		SetSquareBonuses( 0, knightSquareBonuses );
		SetSquareBonuses( 1, knightSquareBonuses );
		SetSquareBonuses( 2, knightSquareBonuses );
		optimization = SimpleSingleStep;
		baseValue = 4000;
		gcID[0] = 'G';
		gcID[1] = 'g';
	}

	static BitBoard64 bitboard[2];
	static BitBoard64 moveArray;
	static General general;
};
class SilverGeneral:
	public PieceType64
{
  public:
	//	construction
	SilverGeneral():
		PieceType64("Silver General", "Silver General", "S", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WSilverGeneral.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BSilverGeneral.bmp";
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability(  0,  1, 1 ) );
		optimization = SimpleSingleStep;
		baseValue = 2750;
	}

	static SilverGeneral silverGeneral;
};

class Waffle:
	public PieceType64
{
  public:
	//	construction
	Waffle():
		PieceType64("Waffle", "Waffle", "_WA", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WElephantWazir.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BElephantWazir.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WWaffle.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BWaffle.bmp";
		AddMovementCapability( MovementCapability(  0,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  0, 1 ) );
		AddMovementCapability( MovementCapability( -2, -2, 1 ) );
		AddMovementCapability( MovementCapability(  2,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  2, 1 ) );
		AddMovementCapability( MovementCapability(  2, -2, 1 ) );
		SetSquareBonuses( 0, waffleSquareBonuses );
		SetSquareBonuses( 1, waffleSquareBonuses );
		SetSquareBonuses( 2, waffleSquareBonuses );
		optimization = SimpleSingleStep;
		baseValue = 2900;
		armyAdjustment = 0;
		gcID[0] = 'E';
		gcID[1] = 'e';
	}

	static Waffle waffle;
};

class Bede:
	public PieceType64
{
  public:
	//	construction
	Bede():
		PieceType64("Bede", "Bede", "_BD", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WBishopWarMachine.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BBishopWarMachine.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WBede.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BBede.bmp";
		AddMovementCapability( MovementCapability(  1,  1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  1, 0 ) );
		AddMovementCapability( MovementCapability(  1, -1, 0 ) );
		AddMovementCapability( MovementCapability( -1, -1, 0 ) );
		AddMovementCapability( MovementCapability(  2,  0, 1 ) );
		AddMovementCapability( MovementCapability( -2,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0,  2, 1 ) );
		AddMovementCapability( MovementCapability(  0, -2, 1 ) );
		SetSquareBonuses( 0, bedeSquareBonuses );
		SetSquareBonuses( 1, bedeSquareBonuses );
		SetSquareBonuses( 2, bedeSquareBonuses );
		baseValue = 4500;
		perCaptureValueBonus = 35;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		gcID[0] = 'A';
		gcID[1] = 'a';
	}

	static Bede bede;
};

class Fad:
	public PieceType64
{
  public:
	//	construction
	Fad():
		PieceType64("Fad", "Fad", "_FA", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WElephantFerzWarMachine.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BElephantFerzWarMachine.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WFAD.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BFAD.bmp";
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  2,  2, 1 ) );
		AddMovementCapability( MovementCapability(  2, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  2, 1 ) );
		AddMovementCapability( MovementCapability(  2,  0, 1 ) );
		AddMovementCapability( MovementCapability( -2,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0,  2, 1 ) );
		AddMovementCapability( MovementCapability(  0, -2, 1 ) );
		SetSquareBonuses( 0, fadSquareBonuses );
		SetSquareBonuses( 1, fadSquareBonuses );
		SetSquareBonuses( 2, fadSquareBonuses );
		optimization = SimpleSingleStep;
		baseValue = 4450;
		armyAdjustment = 0;
		gcID[0] = 'F';
		gcID[1] = 'f';
	}

	static Fad fad;
};

class Archbishop:
	public PieceType64
{
  public:
	//	construction
	Archbishop():
		PieceType64("Archbishop", "Cardinal", "_CA", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WCardinal2.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BCardinal2.bmp";
		bitmapFileNames[PIECE_SET_ALTERNATE][0] = "images\\standard\\WCardinal.bmp";
		bitmapFileNames[PIECE_SET_ALTERNATE][1] = "images\\standard\\BCardinal.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WArchbishop.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BArchbishop.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WKnightBishop.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BKnightBishop.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WKnightBishop.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BKnightBishop.bmp";
		AddMovementCapability( MovementCapability(  1,  1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  1, 0 ) );
		AddMovementCapability( MovementCapability(  1, -1, 0 ) );
		AddMovementCapability( MovementCapability( -1, -1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  2,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -1, 1 ) );
		AddMovementCapability( MovementCapability(  2, -1, 1 ) );
		SetSquareBonuses( 0, archbishopSquareBonuses );
		SetSquareBonuses( 1, archbishopSquareBonuses );
		SetSquareBonuses( 2, archbishopSquareBonuses );
		SetTropismType( DistanceTropism );
		SetTropism( 1, 3 );
		SetTropism( 2, 4 );
		SetTropism( 3, 2 );
		SetTropism( 4, 1 );
		baseValue = 7100;
		perCaptureValueBonus = 20;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		gcID[0] = 'C';
		gcID[1] = 'c';
	}

	static Archbishop archbishop;
};

class ChargingRook:
	public PieceType64
{
  public:
	//	construction
	ChargingRook():
		PieceType64("Charging Rook", "Charging Rook", "_CR", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WForwardRookBackwardsPrince.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BForwardRookBackwardsPrince.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WChargingRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BChargingRook.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 0 ) );
		AddMovementCapability( MovementCapability( -1,  0, 0 ) );
		AddMovementCapability( MovementCapability(  0,  1, 0 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		SetSquareBonuses( 0, rookSquareBonuses );
		SetSquareBonuses( 1, rookSquareBonuses );
		SetSquareBonuses( 2, rookSquareBonuses );
		SetMobility( StandardMobility, 0, 16 );
		SetTropismType( HVDistanceTropism );
		SetTropism( 1, -1 );
		SetTropism( 2, -3 );
		SetTropism( 3, -5 );
		SetTropism( 4, -6 );
		SetTropism( 5, -8 );
		SetTropism( 6, -8 );
		SetTropism( 7, -8 );
		baseValue = 4500;
		perCaptureValueBonus = 30;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		gcID[0] = 'I';
		gcID[1] = 'i';
	}

	static ChargingRook chargingRook;
};

class Fibnif:
	public PieceType64
{
  public:
	//	construction
	Fibnif():
		PieceType64("Fibnif", "Fibnif", "_FN", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WNarrowKnightFerz.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BNarrowKnightFerz.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WFibnif.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BFibnif.bmp";
		AddMovementCapability( MovementCapability( -1,  2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  2, 1 ) );
		AddMovementCapability( MovementCapability( -1, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		SetSquareBonuses( 0, knightSquareBonuses );
		SetSquareBonuses( 1, knightSquareBonuses );
		SetSquareBonuses( 2, knightSquareBonuses );
		baseValue = 3000;
		armyAdjustment = 0;
		optimization = SimpleSingleStep;
		gcID[0] = 'M';
		gcID[1] = 'm';
	}

	static Fibnif fibnif;
};

class ChargingKnight:
	public PieceType64
{
  public:
	//	construction
	ChargingKnight():
		PieceType64("Charging Knight", "Charging Knight", "_CN", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WForwardKnightBackwardsPrince.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BForwardKnightBackwardsPrince.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WChargingKnight.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BChargingKnight.bmp";
		AddMovementCapability( MovementCapability( -1,  2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		baseValue = 3100;
		armyAdjustment = 0;
		optimization = SimpleSingleStep;
		gcID[0] = 'D';
		gcID[1] = 'd';
	}

	static ChargingKnight chargingKnight;
};

class Colonel:
	public PieceType64
{
  public:
	//	construction
	Colonel():
		PieceType64("Colonel", "Colonel", "_CO", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WForwardChancellorPrince.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BForwardChancellorPrince.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WKnightRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BKnightRook.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 0 ) );
		AddMovementCapability( MovementCapability( -1,  0, 0 ) );
		AddMovementCapability( MovementCapability(  0,  1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		SetTropismType( HVDistanceTropism );
		SetTropism( 1, 4 );
		SetTropism( 2, 4 );
		SetTropism( 3, 3 );
		SetTropism( 4, 2 );
		baseValue = 8600;
		perCaptureValueBonus = 20;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		gcID[0] = 'G';
		gcID[1] = 'g';
	}

	static Colonel colonel;
};

class ShortRook:
	public PieceType64
{
  public:
	//	construction
	ShortRook():
		PieceType64("Short Rook", "Short Rook", "_SR", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WHalfRook.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BHalfRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WShortRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BShortRook.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 4 ) );
		AddMovementCapability( MovementCapability( -1,  0, 4 ) );
		AddMovementCapability( MovementCapability(  0,  1, 4 ) );
		AddMovementCapability( MovementCapability(  0, -1, 4 ) );
		SetSquareBonuses( 0, shortRookSquareBonuses );
		SetSquareBonuses( 1, shortRookSquareBonuses );
		SetSquareBonuses( 2, shortRookSquareBonuses );
		SetMobility( StandardMobility, 0, 16 );
		SetTropismType( HVDistanceTropism );
		SetTropism( 1, -1 );
		SetTropism( 2, -3 );
		SetTropism( 3, -5 );
		SetTropism( 4, -6 );
		SetTropism( 5, -8 );
		SetTropism( 6, -8 );
		SetTropism( 7, -8 );
		baseValue = 3750;
		perCaptureValueBonus = 10;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		gcID[0] = 'L';
		gcID[1] = 'l';
	}

	static ShortRook shortRook;
};

class WoodyRook:
	public PieceType64
{
  public:
	//	construction
	WoodyRook():
		PieceType64("Woody Rook", "Woody Rook", "_WR", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WWarMachineWazir.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BWarMachineWazir.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WWoodyRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BWoodyRook.bmp";
		AddMovementCapability( MovementCapability(  0,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0,  2, 1 ) );
		AddMovementCapability( MovementCapability(  2,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  0, 1 ) );
		SetSquareBonuses( 0, woodyRookSquareBonuses );
		SetSquareBonuses( 1, woodyRookSquareBonuses );
		SetSquareBonuses( 2, woodyRookSquareBonuses );
		baseValue = 2900;
		armyAdjustment = 0;
		optimization = SimpleSingleStep;
		gcID[0] = 'W';
		gcID[1] = 'w';
	}

	static WoodyRook woodyRook;
};

class HalfDuck:
	public PieceType64
{
  public:
	//	construction
	HalfDuck():
		PieceType64("Half-Duck", "Half-Duck", "_HD", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WGreatWarMachineFerz.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BGreatWarMachineFerz.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WHalfDuck.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BHalfDuck.bmp";
		AddMovementCapability( MovementCapability(  0,  3, 1 ) );
		AddMovementCapability( MovementCapability(  3,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0, -3, 1 ) );
		AddMovementCapability( MovementCapability( -3,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0,  2, 1 ) );
		AddMovementCapability( MovementCapability(  2,  0, 1 ) );
		AddMovementCapability( MovementCapability(  0, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  0, 1 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		SetSquareBonuses( 0, halfDuckSquareBonuses );
		SetSquareBonuses( 1, halfDuckSquareBonuses );
		SetSquareBonuses( 2, halfDuckSquareBonuses );
		optimization = SimpleSingleStep;
		baseValue = 4500;
		armyAdjustment = 0;
		gcID[0] = 'J';
		gcID[1] = 'j';
	}

	static HalfDuck halfDuck;
};

class Chancellor:
	public PieceType64
{
  public:
	//	construction
	Chancellor():
		PieceType64("Chancellor", "Chancellor", "C", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WMarshal2.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BMarshal2.bmp";
		bitmapFileNames[PIECE_SET_ALTERNATE][0] = "images\\standard\\WChancellor.bmp";
		bitmapFileNames[PIECE_SET_ALTERNATE][1] = "images\\standard\\BChancellor.bmp";
		bitmapFileNames[PIECE_SET_SMALL][0] = "images\\small\\WChancellor.bmp";
		bitmapFileNames[PIECE_SET_SMALL][1] = "images\\small\\BChancellor.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WKnightRook.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BKnightRook.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][0] = "images\\motif\\WKnightRook.bmp";
		bitmapFileNames[PIECE_SET_MOTIF][1] = "images\\motif\\BKnightRook.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 0 ) );
		AddMovementCapability( MovementCapability( -1,  0, 0 ) );
		AddMovementCapability( MovementCapability(  0,  1, 0 ) );
		AddMovementCapability( MovementCapability(  0, -1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  2,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -1, 1 ) );
		AddMovementCapability( MovementCapability(  2, -1, 1 ) );
		SetSquareBonuses( 0, chancellorSquareBonuses );
		SetSquareBonuses( 1, chancellorSquareBonuses );
		SetSquareBonuses( 2, chancellorSquareBonuses );
		SetTropismType( HVDistanceTropism );
		SetTropism( 1, 4 );
		SetTropism( 2, 4 );
		SetTropism( 3, 3 );
		SetTropism( 4, 2 );
		baseValue = 8600;
		perCaptureValueBonus = 40;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
		gcID[0] = 'H';
		gcID[1] = 'h';
	}

	static Chancellor chancellor;
};

class Forequeen:
	public PieceType64
{
  public:
	//	construction
	Forequeen():
		PieceType64("Forequeen", "Forequeen", "_FQ", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WFQueenBKnight.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BFQueenBKnight.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WForequeen.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BForequeen.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 0 ) );
		AddMovementCapability( MovementCapability( -1,  0, 0 ) );
		AddMovementCapability( MovementCapability(  0,  1, 0 ) );
		AddMovementCapability( MovementCapability(  1,  1, 0 ) );
		AddMovementCapability( MovementCapability( -1,  1, 0 ) );
		AddMovementCapability( MovementCapability(  0, -1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -1, 1 ) );
		AddMovementCapability( MovementCapability(  2, -1, 1 ) );
		SetTropismType( DistanceTropism );
		SetTropism( 1, 3 );
		SetTropism( 2, 3 );
		SetTropism( 3, 2 );
		SetTropism( 4, 1 );
		baseValue = 8750;
		perCaptureValueBonus = 55;
		perCaptureBonusThreshold = 11;
		armyAdjustment = 0;
	}

	static Forequeen forequeen;
};

class Bishight:
	public PieceType64
{
  public:
	//	construction
	Bishight():
		PieceType64("Bishight", "Bishight", "_BN", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WFBishopBKnight.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BFBishopBKnight.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WBishight.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BBishight.bmp";
		AddMovementCapability( MovementCapability( -1,  1, 0 ) );
		AddMovementCapability( MovementCapability(  1,  1, 0 ) );
		AddMovementCapability( MovementCapability( -1, -2, 1 ) );
		AddMovementCapability( MovementCapability(  1, -2, 1 ) );
		AddMovementCapability( MovementCapability( -2, -1, 1 ) );
		AddMovementCapability( MovementCapability(  2, -1, 1 ) );
		baseValue = 3075;
		armyAdjustment = 0;
	}

	static Bishight bishight;
};

class Knishop:
	public PieceType64
{
  public:
	//	construction
	Knishop():
		PieceType64("Knishop", "Knishop", "_NB", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WFKnightBBishop.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BFKnightBBishop.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WKnishop.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BKnishop.bmp";
		AddMovementCapability( MovementCapability( -1,  2, 1 ) );
		AddMovementCapability( MovementCapability(  1,  2, 1 ) );
		AddMovementCapability( MovementCapability( -2,  1, 1 ) );
		AddMovementCapability( MovementCapability(  2,  1, 1 ) );
		AddMovementCapability( MovementCapability( -1, -1, 0 ) );
		AddMovementCapability( MovementCapability(  1, -1, 0 ) );
		baseValue = 3075;
		armyAdjustment = 0;
	}

	static Knishop knishop;
};

class Fourfer:
	public PieceType64
{
  public:
	//	construction
	Fourfer():
		PieceType64("Fourfer", "Fourfer", "_FR", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WFortress.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BFortress.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WFourfer.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BFourfer.bmp";
		AddMovementCapability( MovementCapability(  0,  1, 4 ) );
		AddMovementCapability( MovementCapability(  0, -1, 4 ) );
		AddMovementCapability( MovementCapability(  1,  0, 4 ) );
		AddMovementCapability( MovementCapability( -1,  0, 4 ) );
		AddMovementCapability( MovementCapability( -1, -1, 1 ) );
		AddMovementCapability( MovementCapability(  1, -1, 1 ) );
		AddMovementCapability( MovementCapability( -1,  1, 1 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1 ) );
		SetMobility( StandardMobility, 0, 16 );
		SetTropismType( HVDistanceTropism );
		SetTropism( 1, -1 );
		SetTropism( 2, -3 );
		SetTropism( 3, -5 );
		SetTropism( 4, -6 );
		SetTropism( 5, -8 );
		SetTropism( 6, -8 );
		SetTropism( 7, -8 );
		baseValue = 5600;
		perCaptureValueBonus = 40;
		perCaptureBonusThreshold = 11;
		armyAdjustment = 0;
	}

	static Fourfer fourfer;
};

class B4nD:
	public PieceType64
{
  public:
	//	construction
	B4nD():
		PieceType64("B4nD", "B4nD", "_B4", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WHalflingBishop.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BHalflingBishop.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WB4nD.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BB4nD.bmp";
		AddMovementCapability( MovementCapability(  0,  1, 2, Normal, 0, 63, 0, 0, 2 ) );
		AddMovementCapability( MovementCapability(  0, -1, 2, Normal, 0, 63, 0, 0, 2 ) );
		AddMovementCapability( MovementCapability(  1,  0, 2, Normal, 0, 63, 0, 0, 2 ) );
		AddMovementCapability( MovementCapability( -1,  0, 2, Normal, 0, 63, 0, 0, 2 ) );
		AddMovementCapability( MovementCapability( -1, -1, 4 ) );
		AddMovementCapability( MovementCapability(  1, -1, 4 ) );
		AddMovementCapability( MovementCapability( -1,  1, 4 ) );
		AddMovementCapability( MovementCapability(  1,  1, 4 ) );
		baseValue = 3000;
		perCaptureValueBonus = 15;
		perCaptureBonusThreshold = 10;
		armyAdjustment = 0;
	}

	static B4nD b4nD;
};

class N2R4:
	public PieceType64
{
  public:
	//	construction
	N2R4():
		PieceType64("N2R4", "N2R4", "_N2", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WDuke.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BDuke.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WN2R4.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BN2R4.bmp";
		AddMovementCapability( MovementCapability(  0,  1, 4 ) );
		AddMovementCapability( MovementCapability(  0, -1, 4 ) );
		AddMovementCapability( MovementCapability(  1,  0, 4 ) );
		AddMovementCapability( MovementCapability( -1,  0, 4 ) );
		AddMovementCapability( MovementCapability( -1,  2, 2 ) );
		AddMovementCapability( MovementCapability(  1,  2, 2 ) );
		AddMovementCapability( MovementCapability( -2,  1, 2 ) );
		AddMovementCapability( MovementCapability(  2,  1, 2 ) );
		AddMovementCapability( MovementCapability( -1, -2, 2 ) );
		AddMovementCapability( MovementCapability(  1, -2, 2 ) );
		AddMovementCapability( MovementCapability( -2, -1, 2 ) );
		AddMovementCapability( MovementCapability(  2, -1, 2 ) );
		SetTropismType( HVDistanceTropism );
		SetTropism( 1, 4 );
		SetTropism( 2, 4 );
		SetTropism( 3, 3 );
		SetTropism( 4, 2 );
		baseValue = 9000;
		armyAdjustment = 0;
	}

	static N2R4 n2R4;
};

class Cyborg:
	public PieceType64
{
  public:
	//	construction
	Cyborg():
		PieceType64("Cyborg", "Cyborg", "_CY", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WCyborg.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BCyborg.bmp";
		AddMovementCapability( MovementCapability(  1,  1, 2 ) );
		AddMovementCapability( MovementCapability( -1,  1, 2 ) );
		AddMovementCapability( MovementCapability(  1, -1, 2 ) );
		AddMovementCapability( MovementCapability( -1, -1, 2 ) );
		AddMovementCapability( MovementCapability(  1,  0, 1, IguiCaptureOnly ) );
		AddMovementCapability( MovementCapability( -1,  0, 1, IguiCaptureOnly ) );
		AddMovementCapability( MovementCapability(  0,  1, 1, IguiCaptureOnly ) );
		AddMovementCapability( MovementCapability(  0, -1, 1, IguiCaptureOnly ) );
		baseValue = 3050;
		armyAdjustment = 0;
	}

	static Cyborg cyborg;
};

class SV7:
	public PieceType64
{
  public:
	//	construction
	SV7():
		PieceType64("SV7", "SV7", "SV", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WSV7.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BSV7.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 2 ) );
		AddMovementCapability( MovementCapability( -1,  0, 2 ) );
		AddMovementCapability( MovementCapability(  0,  1, 2 ) );
		AddMovementCapability( MovementCapability(  0, -1, 2 ) );
		AddMovementCapability( MovementCapability(  1,  1, 1, IguiCaptureOnly ) );
		AddMovementCapability( MovementCapability( -1,  1, 1, IguiCaptureOnly ) );
		AddMovementCapability( MovementCapability(  1, -1, 1, IguiCaptureOnly ) );
		AddMovementCapability( MovementCapability( -1, -1, 1, IguiCaptureOnly ) );
		baseValue = 3550;
		armyAdjustment = 0;
	}

	static SV7 sv7;
};

class GreaterKnight:
	public PieceType64
{
  public:
	//	construction
	GreaterKnight():
		PieceType64("Greater Knight", "Greater Knight", "_GN", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WSuperKnight.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BSuperKnight.bmp";
		AddMovementCapability( MovementCapability( 0,  0, 2, AreaMover ) );
		baseValue = 4000;
		armyAdjustment = 0;
	}

	static GreaterKnight greaterKnight;
};

class ShortQueen:
	public PieceType64
{
  public:
	//	construction
	ShortQueen():
		PieceType64("Short Queen", "Short Queen", "_SQ", 8, 8)
	{
	}

	virtual void Initialize()
	{
		//	call base class's Initialize function
		PieceType64::Initialize();

		//	initialize all properties to defaults
		bitmapFileNames[PIECE_SET_STANDARD][0] = "images\\standard\\WQueen.bmp";
		bitmapFileNames[PIECE_SET_STANDARD][1] = "images\\standard\\BQueen.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][0] = "images\\abstract\\WQueen.bmp";
		bitmapFileNames[PIECE_SET_ABSTRACT][1] = "images\\abstract\\BQueen.bmp";
		AddMovementCapability( MovementCapability(  1,  0, 3 ) );
		AddMovementCapability( MovementCapability( -1,  0, 3 ) );
		AddMovementCapability( MovementCapability(  0,  1, 3 ) );
		AddMovementCapability( MovementCapability(  0, -1, 3 ) );
		AddMovementCapability( MovementCapability(  1,  1, 3 ) );
		AddMovementCapability( MovementCapability( -1,  1, 3 ) );
		AddMovementCapability( MovementCapability(  1, -1, 3 ) );
		AddMovementCapability( MovementCapability( -1, -1, 3 ) );
		baseValue = 6200;
		armyAdjustment = 0;
	}

	static ShortQueen shortQueen;
};


#endif
